pub struct Instrumented<T> { /* private fields */ }Expand description
A Future that has been instrumented with a tracing Span.
This type is returned by the Instrument extension trait. See that
trait’s documentation for details.
Implementations
Sourceimpl<T> Instrumented<T>
impl<T> Instrumented<T>
Sourcepub fn span_mut(&mut self) -> &mut Span
pub fn span_mut(&mut self) -> &mut Span
Mutably borrows the Span that this type is instrumented by.
Sourcepub fn inner_pin_ref(self: Pin<&Instrumented<T>>) -> Pin<&T>
pub fn inner_pin_ref(self: Pin<&Instrumented<T>>) -> Pin<&T>
Get a pinned reference to the wrapped type.
Sourcepub fn inner_pin_mut(self: Pin<&mut Instrumented<T>>) -> Pin<&mut T>
pub fn inner_pin_mut(self: Pin<&mut Instrumented<T>>) -> Pin<&mut T>
Get a pinned mutable reference to the wrapped type.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the Instrumented, returning the wrapped type.
Note that this drops the span.